@@ -11,11 +11,10 @@ typedef Eo Efl_Net_Control_Access_Point;
 #ifndef _EFL_NET_CONTROL_ACCESS_POINT_EO_TYPES
 #define _EFL_NET_CONTROL_ACCESS_POINT_EO_TYPES
 
+#ifdef EFL_BETA_API_SUPPORT
 /** Provides the access point state.
  *
- * @since 1.19
- *
- * @ingroup Efl_Net_Control_Access_Point
+ * @ingroup Efl_Net_Control_Access_Point_State
  */
 typedef enum
 {
@@ -23,53 +22,53 @@ typedef enum
                                                 * this access point */
   EFL_NET_CONTROL_ACCESS_POINT_STATE_ASSOCIATION, /**< The access point is
                                                    * trying to associate
-                                                   * itself, this is the first
+                                                   * itself. This is the first
                                                    * state after a connection
-                                                   * attempt */
+                                                   * attempt. */
   EFL_NET_CONTROL_ACCESS_POINT_STATE_CONFIGURATION, /**< The access point is
                                                      * configuring itself, such
-                                                     * as DHCP */
-  EFL_NET_CONTROL_ACCESS_POINT_STATE_LOCAL, /**< The access point is connected,
+                                                     * as DHCP. */
+  EFL_NET_CONTROL_ACCESS_POINT_STATE_LOCAL, /**< The access point is connected
                                              * but the internet connection
-                                             * wasn't validated */
+                                             * hasn't been validated. */
   EFL_NET_CONTROL_ACCESS_POINT_STATE_ONLINE, /**< The access point is connected
-                                              * and the internet connected was
-                                              * validated */
+                                              * and the internet connection has
+                                              * been validated. */
   EFL_NET_CONTROL_ACCESS_POINT_STATE_DISCONNECT, /**< The access point is
-                                                  * disconnecting */
-  EFL_NET_CONTROL_ACCESS_POINT_STATE_FAILURE /**< A connection attempt failed,
+                                                  * disconnecting. */
+  EFL_NET_CONTROL_ACCESS_POINT_STATE_FAILURE /**< The connection attempt failed,
                                               * @ref efl_net_control_access_point_error_get
                                               * will provide more details */
 } Efl_Net_Control_Access_Point_State;
+#endif /* EFL_BETA_API_SUPPORT */
 
-/** The connection error reason.
+#ifdef EFL_BETA_API_SUPPORT
+/** The reason for the connection error.
  *
- * @since 1.19
- *
- * @ingroup Efl_Net_Control_Access_Point
+ * @ingroup Efl_Net_Control_Access_Point_Error
  */
 typedef enum
 {
-  EFL_NET_CONTROL_ACCESS_POINT_ERROR_NONE = 0, /**< All right, no errors */
+  EFL_NET_CONTROL_ACCESS_POINT_ERROR_NONE = 0, /**< All OK, no errors */
   EFL_NET_CONTROL_ACCESS_POINT_ERROR_OUT_OF_RANGE, /**< Wireless device is out
-                                                    * of range */
+                                                    * of range. */
   EFL_NET_CONTROL_ACCESS_POINT_ERROR_PIN_MISSING, /**< PIN was required and is
-                                                   * missing */
+                                                   * missing. */
   EFL_NET_CONTROL_ACCESS_POINT_ERROR_DHCP_FAILED, /**< DHCP failed to provide
-                                                   * configuration */
+                                                   * configuration. */
   EFL_NET_CONTROL_ACCESS_POINT_ERROR_CONNECT_FAILED, /**< Could not connect to
-                                                      * access point */
+                                                      * access point. */
   EFL_NET_CONTROL_ACCESS_POINT_ERROR_LOGIN_FAILED /**< Login or authentication
                                                    * information was incorrect,
                                                    * agent_request_input event
-                                                   * may be emitted */
+                                                   * may be emitted. */
 } Efl_Net_Control_Access_Point_Error;
+#endif /* EFL_BETA_API_SUPPORT */
 
+#ifdef EFL_BETA_API_SUPPORT
 /** Bitwise-able securities supported by an access point.
  *
- * @since 1.19
- *
- * @ingroup Efl_Net_Control_Access_Point
+ * @ingroup Efl_Net_Control_Access_Point_Security
  */
 typedef enum
 {
@@ -80,18 +79,18 @@ typedef enum
                                                                * or RSN */
   EFL_NET_CONTROL_ACCESS_POINT_SECURITY_IEEE802_1X = 8 /* 1 >> 3 */ /**< IEEE 802.1X */
 } Efl_Net_Control_Access_Point_Security;
+#endif /* EFL_BETA_API_SUPPORT */
 
+#ifdef EFL_BETA_API_SUPPORT
 /** The method used to configure IPv4
  *
- * @since 1.19
- *
- * @ingroup Efl_Net_Control_Access_Point
+ * @ingroup Efl_Net_Control_Access_Point_Ipv4_Method
  */
 typedef enum
 {
-  EFL_NET_CONTROL_ACCESS_POINT_IPV4_METHOD_OFF = 0, /**< IPv4 is disabled */
+  EFL_NET_CONTROL_ACCESS_POINT_IPV4_METHOD_OFF = 0, /**< IPv4 is disabled. */
   EFL_NET_CONTROL_ACCESS_POINT_IPV4_METHOD_DHCP, /**< IPv4 is configured using
-                                                  * DHCP */
+                                                  * DHCP. */
   EFL_NET_CONTROL_ACCESS_POINT_IPV4_METHOD_MANUAL, /**< IPv4 is manually set
                                                     * using address, netmask
                                                     * and gateway */
@@ -99,80 +98,80 @@ typedef enum
                                                   * @ref efl_net_control_access_point_configuration_ipv4_get
                                                   */
 } Efl_Net_Control_Access_Point_Ipv4_Method;
+#endif /* EFL_BETA_API_SUPPORT */
 
+#ifdef EFL_BETA_API_SUPPORT
 /** The method used to configure IPv6
  *
- * @since 1.19
- *
- * @ingroup Efl_Net_Control_Access_Point
+ * @ingroup Efl_Net_Control_Access_Point_Ipv6_Method
  */
 typedef enum
 {
-  EFL_NET_CONTROL_ACCESS_POINT_IPV6_METHOD_OFF = 0, /**< IPv6 is disabled */
+  EFL_NET_CONTROL_ACCESS_POINT_IPV6_METHOD_OFF = 0, /**< IPv6 is disabled. */
   EFL_NET_CONTROL_ACCESS_POINT_IPV6_METHOD_FIXED, /**< IPv6 is fixed by operator
-                                                   * and cannot be changed */
+                                                   * and cannot be changed. */
   EFL_NET_CONTROL_ACCESS_POINT_IPV6_METHOD_MANUAL, /**< IPv6 is manually set
                                                     * using address, netmask
-                                                    * and gateway */
+                                                    * and gateway. */
   EFL_NET_CONTROL_ACCESS_POINT_IPV6_METHOD_AUTO_PRIVACY_NONE, /**< IPv6 is set using dhcp or using a
-                                                               * tunnel6to4, no privacy extensions
-                                                               * should be used */
+                                                               * tunnel6to4. No privacy extensions
+                                                               * should be used. */
   EFL_NET_CONTROL_ACCESS_POINT_IPV6_METHOD_AUTO_PRIVACY_PUBLIC, /**< IPv6 is set using dhcp or using a
                                                                  * tunnel6to4, privacy extensions are
                                                                  * used and the system prefers a public
-                                                                 * IP address over temporary addresses
+                                                                 * IP address over temporary addresses.
                                                                  */
   EFL_NET_CONTROL_ACCESS_POINT_IPV6_METHOD_AUTO_PRIVACY_TEMPORARY, /**< IPv6 is set using dhcp or using a
                                                                     * tunnel6to4, privacy extensions are
                                                                     * used and the system prefers a
                                                                     * temporary IP address over public
-                                                                    * addresses */
+                                                                    * addresses. */
   EFL_NET_CONTROL_ACCESS_POINT_IPV6_METHOD_TUNNEL6TO4, /**< IPv6 was configured
                                                         * using a 6-to-4
                                                         * tunnel. This cannot
                                                         * be set by the user,
-                                                        * which is expected to
-                                                        * set "auto" instead */
+                                                        * which is set to
+                                                        * "auto" instead */
   EFL_NET_CONTROL_ACCESS_POINT_IPV6_METHOD_UNSET /**< Only to be used with
                                                   * @ref efl_net_control_access_point_configuration_ipv6_get
                                                   */
 } Efl_Net_Control_Access_Point_Ipv6_Method;
+#endif /* EFL_BETA_API_SUPPORT */
 
-/** The method used to configure Proxy.
+#ifdef EFL_BETA_API_SUPPORT
+/** The method used to configure Proxies.
  *
- * @since 1.19
- *
- * @ingroup Efl_Net_Control_Access_Point
+ * @ingroup Efl_Net_Control_Access_Point_Proxy_Method
  */
 typedef enum
 {
   EFL_NET_CONTROL_ACCESS_POINT_PROXY_METHOD_OFF = 0, /**< Direct connection to
                                                       * the internet, no proxy
-                                                      * to be used */
+                                                      * used. */
   EFL_NET_CONTROL_ACCESS_POINT_PROXY_METHOD_AUTO, /**< Proxy is autoconfigured
                                                    * using
                                                    * Proxy-Auto-Configuration
-                                                   * (PAC) using given URL */
+                                                   * (PAC) using given URL. */
   EFL_NET_CONTROL_ACCESS_POINT_PROXY_METHOD_MANUAL, /**< Proxy is configured
                                                      * manually using servers
-                                                     * and excludes */
+                                                     * and excludes. */
   EFL_NET_CONTROL_ACCESS_POINT_PROXY_METHOD_UNSET /**< Only to be used with
-                                                   * @ref efl_net_control_access_point_configuration_proxy_get
+                                                   * @ref efl_net_control_access_point_configuration_proxy_get.
                                                    */
 } Efl_Net_Control_Access_Point_Proxy_Method;
+#endif /* EFL_BETA_API_SUPPORT */
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief An access point for network connectivity.
  *
- * The @ref Efl_Net_Control is composed of multiple technologies, each create
- * access points to allow configuration and connection.
+ * The @ref Efl_Net_Control_Manager is composed of multiple technologies, each
+ * create access points to allow configuration and connection.
  *
- * An application willing to just get a network connection should prefer to use
- * the @Efl.Net.Session instead.
- *
- * @since 1.19
+ * An application requiring only a network connection can just use a
+ * @ref Efl_Net_Session instead.
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
@@ -198,25 +197,24 @@ EWAPI const Efl_Class *efl_net_control_access_point_class_get(void);
  * connection was already ongoing) and EALREADY (the connection was already
  * established).
  *
- * @return Future for asynchronous connect
+ * @param[in] obj The object.
  *
- * @since 1.19
+ * @return Future for asynchronous connect
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI Efl_Future *efl_net_control_access_point_connect(Eo *obj);
+EOAPI Eina_Future *efl_net_control_access_point_connect(Eo *obj) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
 
 /**
  * @brief Disconnects from this access point.
  *
- * When disconnected a previously connected access point it won't be forgotten.
- * The configuration and other details such as priority and passphrase will be
- * available for a future re-connection with call to
- * @ref efl_net_control_access_point_connect. If it is desired to disconnect
- * and forget all access point information, use
+ * When disconnected previously connected access points won't be forgotten. The
+ * configuration and other details such as priority and passphrase will be
+ * available for future re-connection with a call to
+ * @ref efl_net_control_access_point_connect. If you need to disconnect and
+ * forget all access point information, use
  * @ref efl_net_control_access_point_forget instead.
- *
- * @since 1.19
+ * @param[in] obj The object.
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
@@ -226,25 +224,23 @@ EOAPI void efl_net_control_access_point_disconnect(Eo *obj);
  * @brief Disconnects and forgets about this access point.
  *
  * Successful @ref efl_net_control_access_point_connect will always remember
- * the access point for future re-connections. This method reverts that by
- * disconnecting and forgetting about the access point and its configuration,
- * which will set the @ref efl_net_control_access_point_remembered_get to
- * @c false.
- *
- * @since 1.19
+ * the access point for future re-connections. This method overrides this by
+ * disconnecting and forgetting the access point and its configuration, which
+ * will set @ref efl_net_control_access_point_remembered_get to @c false.
+ * @param[in] obj The object.
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
 EOAPI void efl_net_control_access_point_forget(Eo *obj);
 
 /**
- * @brief The current state of this access point.
+ * @brief The current state of the access point.
  *
  * Whenever the state changes, "changed" will be emitted.
  *
- * @return Access point state
+ * @param[in] obj The object.
  *
- * @since 1.19
+ * @return Access point state
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
@@ -253,9 +249,9 @@ EOAPI Efl_Net_Control_Access_Point_State efl_net_control_access_point_state_get(
 /**
  * @brief If the access point is in error state, this states the error.
  *
- * @return Access point error
+ * @param[in] obj The object.
  *
- * @since 1.19
+ * @return Access point error
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
@@ -266,33 +262,32 @@ EOAPI Efl_Net_Control_Access_Point_Error efl_net_control_access_point_error_get(
  *
  * For hidden WiFi networks, this is empty.
  *
- * @return Access point name
+ * @param[in] obj The object.
  *
- * @since 1.19
+ * @return Access point name
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI const char *efl_net_control_access_point_name_get(const Eo *obj);
+EOAPI const char *efl_net_control_access_point_ssid_get(const Eo *obj);
 
 /**
  * @brief The access point priority in the current access point listing.
  *
  * This property is dynamic and reflects the index of the access point in the
  * current access points list. As access points may come and go, the value may
- * change at any time and notified with "changed" event.
+ * change at any time and send notifications via the "changed" event.
  *
  * If set, then it will reorder priorities, moving all other services at equal
  * or higher priority up. To move as the first (most priority), then use 0. To
  * move as the last priority, use UINT32_MAX or the last known priority + 1.
  *
- * @note Only remembered access points may be reordered among themselves. Those
- * that are not remembered will always come last in random order defined by the
- * backend.
+ * @note Only stored access points may be reordered among themselves. Those
+ * that are not remembered will always come last in a random order defined by
+ * the backend.
  *
+ * @param[in] obj The object.
  * @param[in] priority Access point priority in listing
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Control_Access_Point
  */
 EOAPI void efl_net_control_access_point_priority_set(Eo *obj, unsigned int priority);
@@ -302,20 +297,20 @@ EOAPI void efl_net_control_access_point_priority_set(Eo *obj, unsigned int prior
  *
  * This property is dynamic and reflects the index of the access point in the
  * current access points list. As access points may come and go, the value may
- * change at any time and notified with "changed" event.
+ * change at any time and send notifications via the "changed" event.
  *
  * If set, then it will reorder priorities, moving all other services at equal
  * or higher priority up. To move as the first (most priority), then use 0. To
  * move as the last priority, use UINT32_MAX or the last known priority + 1.
  *
- * @note Only remembered access points may be reordered among themselves. Those
- * that are not remembered will always come last in random order defined by the
- * backend.
+ * @note Only stored access points may be reordered among themselves. Those
+ * that are not remembered will always come last in a random order defined by
+ * the backend.
+ *
+ * @param[in] obj The object.
  *
  * @return Access point priority in listing
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Control_Access_Point
  */
 EOAPI unsigned int efl_net_control_access_point_priority_get(const Eo *obj);
@@ -323,9 +318,9 @@ EOAPI unsigned int efl_net_control_access_point_priority_get(const Eo *obj);
 /**
  * @brief The technology that generated this access point
  *
- * @return Access point technology
+ * @param[in] obj The object.
  *
- * @since 1.19
+ * @return Access point technology
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
@@ -334,9 +329,9 @@ EOAPI Efl_Net_Control_Technology *efl_net_control_access_point_technology_get(co
 /**
  * @brief Signal strength percentage in 0-100
  *
- * @return Access point signal strength
+ * @param[in] obj The object.
  *
- * @since 1.19
+ * @return Access point signal strength
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
@@ -345,11 +340,11 @@ EOAPI uint8_t efl_net_control_access_point_strength_get(const Eo *obj);
 /**
  * @brief If it's a cellular access point and it's on roaming.
  *
+ * @param[in] obj The object.
+ *
  * @return @c true if the access point is cellular and uses roaming, @c false
  * otherwise
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Control_Access_Point
  */
 EOAPI Eina_Bool efl_net_control_access_point_roaming_get(const Eo *obj);
@@ -364,11 +359,10 @@ EOAPI Eina_Bool efl_net_control_access_point_roaming_get(const Eo *obj);
  * An access point is only connected automatically if there are no other
  * connected and if it is not on roaming.
  *
+ * @param[in] obj The object.
  * @param[in] auto_connect @c true when auto-connect is set for this access
  * point, @c false otherwise
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Control_Access_Point
  */
 EOAPI void efl_net_control_access_point_auto_connect_set(Eo *obj, Eina_Bool auto_connect);
@@ -383,11 +377,11 @@ EOAPI void efl_net_control_access_point_auto_connect_set(Eo *obj, Eina_Bool auto
  * An access point is only connected automatically if there are no other
  * connected and if it is not on roaming.
  *
+ * @param[in] obj The object.
+ *
  * @return @c true when auto-connect is set for this access point, @c false
  * otherwise
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Control_Access_Point
  */
 EOAPI Eina_Bool efl_net_control_access_point_auto_connect_get(const Eo *obj);
@@ -398,9 +392,9 @@ EOAPI Eina_Bool efl_net_control_access_point_auto_connect_get(const Eo *obj);
  * To forget about this access point, call
  * @ref efl_net_control_access_point_forget.
  *
- * @return @c true if this access point will be remembered, @c false otherwise
+ * @param[in] obj The object.
  *
- * @since 1.19
+ * @return @c true if this access point will be remembered, @c false otherwise
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
@@ -410,9 +404,9 @@ EOAPI Eina_Bool efl_net_control_access_point_remembered_get(const Eo *obj);
  * @brief Immutable access points are those defined in configuration files and
  * its properties can't be changed using API.
  *
- * @return @c true is this access point is immutable, @c false otherwise
+ * @param[in] obj The object.
  *
- * @since 1.19
+ * @return @c true is this access point is immutable, @c false otherwise
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
@@ -421,9 +415,9 @@ EOAPI Eina_Bool efl_net_control_access_point_immutable_get(const Eo *obj);
 /**
  * @brief Security options such as WEP, WPS, PSK or none (open).
  *
- * @return Bitwise OR of security supported by this access point
+ * @param[in] obj The object.
  *
- * @since 1.19
+ * @return Bitwise OR of security supported by this access point
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
@@ -432,62 +426,61 @@ EOAPI Efl_Net_Control_Access_Point_Security efl_net_control_access_point_securit
 /**
  * @brief DNS (Domain Name Servers) in use for this access point.
  *
- * These are the actual values in use, configure them using
- * @ref efl_net_control_access_point_configuration_name_servers_get, which may
- * generate change to this property, being notified with the "changed" event.
+ * These are the actual values used. Configure them using
+ * @ref efl_net_control_access_point_configuration_name_servers_get. This may
+ * generate changes to this property, triggering the "changed" event.
+ *
+ * @param[in] obj The object.
  *
  * @return Iterator to DNS server
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI Eina_Iterator *efl_net_control_access_point_name_servers_get(const Eo *obj);
+EOAPI Eina_Iterator *efl_net_control_access_point_name_servers_get(const Eo *obj) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
 
 /**
  * @brief NTP (Time Server) in use for this access point.
  *
- * These are the actual values in use, configure them using
- * @ref efl_net_control_access_point_configuration_time_servers_get, which may
- * generate change to this property, being notified with the "changed" event.
+ * These are the actual values used. Configure them using
+ * @ref efl_net_control_access_point_configuration_name_servers_get. This may
+ * generate changes to this property, triggering the "changed" event.
+ *
+ * @param[in] obj The object.
  *
  * @return Iterator to time server
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI Eina_Iterator *efl_net_control_access_point_time_servers_get(const Eo *obj);
+EOAPI Eina_Iterator *efl_net_control_access_point_time_servers_get(const Eo *obj) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
 
 /**
  * @brief Searches domains in use for this access point.
  *
- * These are the actual values in use, configure them using
- * @ref efl_net_control_access_point_configuration_domains_get, which may
- * generate change to this property, being notified with the "changed" event.
+ * These are the actual values used. Configure them using
+ * @ref efl_net_control_access_point_configuration_name_servers_get. This may
+ * generate changes to this property, triggering the "changed" event.
+ *
+ * @param[in] obj The object.
  *
  * @return Iterator to search domains
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI Eina_Iterator *efl_net_control_access_point_domains_get(const Eo *obj);
+EOAPI Eina_Iterator *efl_net_control_access_point_domains_get(const Eo *obj) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
 
 /**
  * @brief IPv4 in use for this access point.
  *
- * These are the actual values in use, configure them using
- * @ref efl_net_control_access_point_configuration_ipv4_get, which may generate
- * change to this property, being notified with the "changed" event.
+ * These are the actual values used. Configure them using
+ * @ref efl_net_control_access_point_configuration_name_servers_get. This may
+ * generate changes to this property, triggering the "changed" event.
  *
+ * @param[in] obj The object.
  * @param[out] method IPv4 method
  * @param[out] address IPv4 address
  * @param[out] netmask IPv4 netmask
  * @param[out] gateway IPv4 gateway
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Control_Access_Point
  */
 EOAPI void efl_net_control_access_point_ipv4_get(const Eo *obj, Efl_Net_Control_Access_Point_Ipv4_Method *method, const char **address, const char **netmask, const char **gateway);
@@ -495,18 +488,17 @@ EOAPI void efl_net_control_access_point_ipv4_get(const Eo *obj, Efl_Net_Control_
 /**
  * @brief IPv6 in use for this access point.
  *
- * These are the actual values in use, configure them using
- * @ref efl_net_control_access_point_configuration_ipv6_get, which may generate
- * change to this property, being notified with the "changed" event.
+ * These are the actual values used. Configure them using
+ * @ref efl_net_control_access_point_configuration_name_servers_get. This may
+ * generate changes to this property, triggering the "changed" event.
  *
+ * @param[in] obj The object.
  * @param[out] method IPv6 method
  * @param[out] address IPv6 address
  * @param[out] prefix_length IPv6 prefix length
  * @param[out] netmask IPv6 netmask
  * @param[out] gateway IPv6 gateway
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Control_Access_Point
  */
 EOAPI void efl_net_control_access_point_ipv6_get(const Eo *obj, Efl_Net_Control_Access_Point_Ipv6_Method *method, const char **address, uint8_t *prefix_length, const char **netmask, const char **gateway);
@@ -514,10 +506,11 @@ EOAPI void efl_net_control_access_point_ipv6_get(const Eo *obj, Efl_Net_Control_
 /**
  * @brief Proxy in use for this access point.
  *
- * These are the actual values in use, configure them using
- * @ref efl_net_control_access_point_configuration_proxy_get, which may
- * generate change to this property, being notified with the "changed" event.
+ * These are the actual values used. Configure them using
+ * @ref efl_net_control_access_point_configuration_name_servers_get. This may
+ * generate changes to this property, triggering the "changed" event.
  *
+ * @param[in] obj The object.
  * @param[out] method Proxy method
  * @param[out] url If @ref EFL_NET_CONTROL_ACCESS_POINT_PROXY_METHOD_AUTO, then
  * states the URL to use for proxy auto-configuration
@@ -529,123 +522,117 @@ EOAPI void efl_net_control_access_point_ipv6_get(const Eo *obj, Efl_Net_Control_
  * or patterns to exclude from proxy access, such as "localhost",
  * ".domain.com", or "10.0.0.0..."
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI void efl_net_control_access_point_proxy_get(const Eo *obj, Efl_Net_Control_Access_Point_Proxy_Method *method, const char **url, Eina_Iterator **servers, Eina_Iterator **excludes);
+EOAPI void efl_net_control_access_point_proxy_get(const Eo *obj, Efl_Net_Control_Access_Point_Proxy_Method *method, const char **url, Eina_Iterator **servers EFL_TRANSFER_OWNERSHIP, Eina_Iterator **excludes EFL_TRANSFER_OWNERSHIP);
 
 /**
  * @brief DNS (Domain Name Servers) configured by user for this access point.
  *
- * These are the user configured values, that will be applied by the backend
+ * These are user configured values, which will be applied by the backend
  * system and in turn may result in "changed" event to notify of
  * @ref efl_net_control_access_point_name_servers_get property with the actual
  * value in use, which may differ from this.
  *
+ * @param[in] obj The object.
  * @param[in] name_servers Iterator to user DNS server
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI void efl_net_control_access_point_configuration_name_servers_set(Eo *obj, Eina_Iterator *name_servers);
+EOAPI void efl_net_control_access_point_configuration_name_servers_set(Eo *obj, Eina_Iterator *name_servers EFL_TRANSFER_OWNERSHIP);
 
 /**
  * @brief DNS (Domain Name Servers) configured by user for this access point.
  *
- * These are the user configured values, that will be applied by the backend
+ * These are user configured values, which will be applied by the backend
  * system and in turn may result in "changed" event to notify of
  * @ref efl_net_control_access_point_name_servers_get property with the actual
  * value in use, which may differ from this.
  *
+ * @param[in] obj The object.
+ *
  * @return Iterator to user DNS server
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI Eina_Iterator *efl_net_control_access_point_configuration_name_servers_get(const Eo *obj);
+EOAPI Eina_Iterator *efl_net_control_access_point_configuration_name_servers_get(const Eo *obj) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
 
 /**
  * @brief NTP (Time Server) configured by user for this access point.
  *
- * These are the user configured values, that will be applied by the backend
+ * These are user configured values, which will be applied by the backend
  * system and in turn may result in "changed" event to notify of
- * @ref efl_net_control_access_point_time_servers_get property with the actual
+ * @ref efl_net_control_access_point_name_servers_get property with the actual
  * value in use, which may differ from this.
  *
+ * @param[in] obj The object.
  * @param[in] time_servers Iterator to user time server
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI void efl_net_control_access_point_configuration_time_servers_set(Eo *obj, Eina_Iterator *time_servers);
+EOAPI void efl_net_control_access_point_configuration_time_servers_set(Eo *obj, Eina_Iterator *time_servers EFL_TRANSFER_OWNERSHIP);
 
 /**
  * @brief NTP (Time Server) configured by user for this access point.
  *
- * These are the user configured values, that will be applied by the backend
+ * These are user configured values, which will be applied by the backend
  * system and in turn may result in "changed" event to notify of
- * @ref efl_net_control_access_point_time_servers_get property with the actual
+ * @ref efl_net_control_access_point_name_servers_get property with the actual
  * value in use, which may differ from this.
  *
+ * @param[in] obj The object.
+ *
  * @return Iterator to user time server
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI Eina_Iterator *efl_net_control_access_point_configuration_time_servers_get(const Eo *obj);
+EOAPI Eina_Iterator *efl_net_control_access_point_configuration_time_servers_get(const Eo *obj) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
 
 /**
  * @brief Searches domains configured by user for this access point.
  *
- * These are the user configured values, that will be applied by the backend
+ * These are user configured values, which will be applied by the backend
  * system and in turn may result in "changed" event to notify of
  * @ref efl_net_control_access_point_domains_get property with the actual value
  * in use, which may differ from this.
  *
+ * @param[in] obj The object.
  * @param[in] domains Iterator to user search domains
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI void efl_net_control_access_point_configuration_domains_set(Eo *obj, Eina_Iterator *domains);
+EOAPI void efl_net_control_access_point_configuration_domains_set(Eo *obj, Eina_Iterator *domains EFL_TRANSFER_OWNERSHIP);
 
 /**
  * @brief Searches domains configured by user for this access point.
  *
- * These are the user configured values, that will be applied by the backend
+ * These are user configured values, which will be applied by the backend
  * system and in turn may result in "changed" event to notify of
  * @ref efl_net_control_access_point_domains_get property with the actual value
  * in use, which may differ from this.
  *
+ * @param[in] obj The object.
+ *
  * @return Iterator to user search domains
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI Eina_Iterator *efl_net_control_access_point_configuration_domains_get(const Eo *obj);
+EOAPI Eina_Iterator *efl_net_control_access_point_configuration_domains_get(const Eo *obj) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
 
 /**
  * @brief IPv4 configured by user for this access point.
  *
- * These are the user configured values, that will be applied by the backend
+ * These are user configured values, which will be applied by the backend
  * system and in turn may result in "changed" event to notify of
  * @ref efl_net_control_access_point_ipv4_get property with the actual value in
  * use, which may differ from this.
  *
+ * @param[in] obj The object.
  * @param[in] method IPv4 method
  * @param[in] address IPv4 address
  * @param[in] netmask IPv4 netmask
  * @param[in] gateway IPv4 gateway
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Control_Access_Point
  */
 EOAPI void efl_net_control_access_point_configuration_ipv4_set(Eo *obj, Efl_Net_Control_Access_Point_Ipv4_Method method, const char *address, const char *netmask, const char *gateway);
@@ -653,18 +640,17 @@ EOAPI void efl_net_control_access_point_configuration_ipv4_set(Eo *obj, Efl_Net_
 /**
  * @brief IPv4 configured by user for this access point.
  *
- * These are the user configured values, that will be applied by the backend
+ * These are user configured values, which will be applied by the backend
  * system and in turn may result in "changed" event to notify of
  * @ref efl_net_control_access_point_ipv4_get property with the actual value in
  * use, which may differ from this.
  *
+ * @param[in] obj The object.
  * @param[out] method IPv4 method
  * @param[out] address IPv4 address
  * @param[out] netmask IPv4 netmask
  * @param[out] gateway IPv4 gateway
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Control_Access_Point
  */
 EOAPI void efl_net_control_access_point_configuration_ipv4_get(const Eo *obj, Efl_Net_Control_Access_Point_Ipv4_Method *method, const char **address, const char **netmask, const char **gateway);
@@ -672,19 +658,18 @@ EOAPI void efl_net_control_access_point_configuration_ipv4_get(const Eo *obj, Ef
 /**
  * @brief IPv6 configured by user for this access point.
  *
- * These are the user configured values, that will be applied by the backend
+ * These are user configured values, which will be applied by the backend
  * system and in turn may result in "changed" event to notify of
  * @ref efl_net_control_access_point_ipv6_get property with the actual value in
  * use, which may differ from this.
  *
+ * @param[in] obj The object.
  * @param[in] method IPv6 method
  * @param[in] address IPv6 address
  * @param[in] prefix_length IPv6 prefix length
  * @param[in] netmask IPv6 netmask
  * @param[in] gateway IPv6 gateway
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Control_Access_Point
  */
 EOAPI void efl_net_control_access_point_configuration_ipv6_set(Eo *obj, Efl_Net_Control_Access_Point_Ipv6_Method method, const char *address, uint8_t prefix_length, const char *netmask, const char *gateway);
@@ -692,19 +677,18 @@ EOAPI void efl_net_control_access_point_configuration_ipv6_set(Eo *obj, Efl_Net_
 /**
  * @brief IPv6 configured by user for this access point.
  *
- * These are the user configured values, that will be applied by the backend
+ * These are user configured values, which will be applied by the backend
  * system and in turn may result in "changed" event to notify of
  * @ref efl_net_control_access_point_ipv6_get property with the actual value in
  * use, which may differ from this.
  *
+ * @param[in] obj The object.
  * @param[out] method IPv6 method
  * @param[out] address IPv6 address
  * @param[out] prefix_length IPv6 prefix length
  * @param[out] netmask IPv6 netmask
  * @param[out] gateway IPv6 gateway
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Control_Access_Point
  */
 EOAPI void efl_net_control_access_point_configuration_ipv6_get(const Eo *obj, Efl_Net_Control_Access_Point_Ipv6_Method *method, const char **address, uint8_t *prefix_length, const char **netmask, const char **gateway);
@@ -712,11 +696,12 @@ EOAPI void efl_net_control_access_point_configuration_ipv6_get(const Eo *obj, Ef
 /**
  * @brief Proxy configured by user for this access point.
  *
- * These are the user configured values, that will be applied by the backend
+ * These are user configured values, which will be applied by the backend
  * system and in turn may result in "changed" event to notify of
  * @ref efl_net_control_access_point_proxy_get property with the actual value
  * in use, which may differ from this.
  *
+ * @param[in] obj The object.
  * @param[in] method Proxy method
  * @param[in] url If @ref EFL_NET_CONTROL_ACCESS_POINT_PROXY_METHOD_AUTO, then
  * states the URL to use for proxy auto-configuration
@@ -728,20 +713,19 @@ EOAPI void efl_net_control_access_point_configuration_ipv6_get(const Eo *obj, Ef
  * or patterns to exclude from proxy access, such as "localhost",
  * ".domain.com", or "10.0.0.0..."
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI void efl_net_control_access_point_configuration_proxy_set(Eo *obj, Efl_Net_Control_Access_Point_Proxy_Method method, const char *url, Eina_Iterator *servers, Eina_Iterator *excludes);
+EOAPI void efl_net_control_access_point_configuration_proxy_set(Eo *obj, Efl_Net_Control_Access_Point_Proxy_Method method, const char *url, Eina_Iterator *servers EFL_TRANSFER_OWNERSHIP, Eina_Iterator *excludes EFL_TRANSFER_OWNERSHIP);
 
 /**
  * @brief Proxy configured by user for this access point.
  *
- * These are the user configured values, that will be applied by the backend
+ * These are user configured values, which will be applied by the backend
  * system and in turn may result in "changed" event to notify of
  * @ref efl_net_control_access_point_proxy_get property with the actual value
  * in use, which may differ from this.
  *
+ * @param[in] obj The object.
  * @param[out] method Proxy method
  * @param[out] url If @ref EFL_NET_CONTROL_ACCESS_POINT_PROXY_METHOD_AUTO, then
  * states the URL to use for proxy auto-configuration
@@ -753,20 +737,17 @@ EOAPI void efl_net_control_access_point_configuration_proxy_set(Eo *obj, Efl_Net
  * or patterns to exclude from proxy access, such as "localhost",
  * ".domain.com", or "10.0.0.0..."
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI void efl_net_control_access_point_configuration_proxy_get(const Eo *obj, Efl_Net_Control_Access_Point_Proxy_Method *method, const char **url, Eina_Iterator **servers, Eina_Iterator **excludes);
+EOAPI void efl_net_control_access_point_configuration_proxy_get(const Eo *obj, Efl_Net_Control_Access_Point_Proxy_Method *method, const char **url, Eina_Iterator **servers EFL_TRANSFER_OWNERSHIP, Eina_Iterator **excludes EFL_TRANSFER_OWNERSHIP);
 
 EWAPI extern const Efl_Event_Description _EFL_NET_CONTROL_ACCESS_POINT_EVENT_CHANGED;
 
 /** Called when some properties were changed.
- *
- * @since 1.19
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
 #define EFL_NET_CONTROL_ACCESS_POINT_EVENT_CHANGED (&(_EFL_NET_CONTROL_ACCESS_POINT_EVENT_CHANGED))
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
