@@ -15,15 +15,21 @@ typedef Eo Efl_Ui_Widget;
  *
  * @since 1.22
  *
- * @ingroup Efl_Ui
+ * @ingroup Efl_Ui_Widget_Focus_State
  */
 typedef struct _Efl_Ui_Widget_Focus_State
 {
   Efl_Ui_Focus_Manager *manager; /**< The manager where the widget is registered
-                                  * in */
+                                  * in
+                                  *
+                                  * @since 1.22 */
   Efl_Ui_Focus_Object *parent; /**< The parent the widget is using as logical
-                                * parent */
-  Eina_Bool logical; /**< @c true if this is registered as logical currently */
+                                * parent
+                                *
+                                * @since 1.22 */
+  Eina_Bool logical; /**< @c true if this is registered as logical currently
+                      *
+                      * @since 1.22 */
 } Efl_Ui_Widget_Focus_State;
 
 
